@@ -25,6 +25,9 @@ void load_settings(const char *fname);
 void unload_settings(void);
 
 xmlNodePtr get_region(const char *number, const char *mcc);
+xmlChar *get_region_code(xmlNodePtr region);
+xmlChar *get_region_name(xmlNodePtr region);
 xmlChar *get_region_prefix(xmlNodePtr region);
 const char *skip_prefix(xmlNodePtr region, const char *number);
 xmlNodePtr get_region_directory(xmlNodePtr region, const char *number);
+FILE *get_region_text(xmlNodePtr region, const char *number);
